/*
   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   SLEPc - Scalable Library for Eigenvalue Problem Computations
   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain

   This file is part of SLEPc.
   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*/
/*
   Include all top-level SLEPc functionality
*/

#pragma once

/* MANSEC = Sys */

#include <slepcsvd.h>
#include <slepcpep.h>
#include <slepcnep.h>
#include <slepcmfn.h>
#include <slepclme.h>
